@@ -2,9 +2,9 @@ package Catalyst::Plugin::RapidApp::NavCore::NavTree;
 use strict;
 use warnings;
 use Moose;
-extends 'RapidApp::AppNavTree';
+extends 'RapidApp::Module::NavTree';
 
-use RapidApp::Include qw(sugar perlutil);
+use RapidApp::Util qw(:all);
 
 has 'plugin_config', is => 'ro', lazy => 1, default => sub {
   my $self = shift;
