@@ -24,7 +24,7 @@ use Module::Runtime;
 use Catalyst::Utils;
 use Class::Load 'is_class_loaded';
 
-use RapidApp::Include qw(sugar perlutil);
+use RapidApp::Util qw(:all);
 
 has 'connect_info', is => 'ro', lazy => 1, default => sub {
   my $self = shift;
@@ -66,6 +66,8 @@ has 'crud_profile',
 has 'no_cleanup',      is => 'ro', isa => Bool, default => sub {0};
 has 'isolate_app_tmp', is => 'ro', isa => Bool, default => 0;
 
+has 'metakeys', is => 'ro', isa => Maybe[Any], default => sub { undef };
+
 has '_def_ns_pfx', is => 'ro', isa => Str, default => sub { 'rDbicApp' };
 
 has 'app_namespace', is => 'ro', isa => Str,  lazy => 1, default => sub { 
@@ -252,7 +254,8 @@ sub _bootstrap {
         dsn            => $self->dsn,
         'model-name'   => $self->model_name,
         'schema-class' => $self->schema_class,
-        crud_profile   => $self->crud_profile
+        crud_profile   => $self->crud_profile,
+        metakeys       => $self->metakeys
       },
       traits => ['RapidApp::Helper::Traits::RapidDbic'],
       name   => $name,
@@ -588,6 +591,14 @@ L<RapidApp>
 
 L<Plack::Component>
 
+=item * 
+
+L<Catalyst Advent 2014 - Day 16|http://www.catalystframework.org/calendar/2014/16>
+
+=item * 
+
+L<Catalyst Advent 2014 - Day 17|http://www.catalystframework.org/calendar/2014/17>
+
 =back
 
 
