@@ -12,10 +12,10 @@ use Sub::Name qw/subname/;
 # a Result class for use in configuring various modules that
 # consume/use a DBIC Source
 
-use RapidApp::Include qw(sugar perlutil);
+use RapidApp::Util qw(:all);
 
 use RapidApp::TableSpec;
-use RapidApp::DbicAppCombo2;
+use RapidApp::Module::DbicCombo;
 
 #__PACKAGE__->load_components(qw/IntrospectableM2M/);
 
