@@ -3,7 +3,7 @@ use strict;
 use Moose;
 use Moose::Util::TypeConstraints;
 
-use RapidApp::Include qw(sugar perlutil);
+use RapidApp::Util qw(:all);
 
 =head1 ColSpec format 'include_colspec'
 
@@ -73,23 +73,35 @@ are ignored.
 
 =cut
 
-subtype 'ColSpecStr', as 'Str', where {
-	/\s+/ and warn "ColSpec '$_' is invalid because it contains whitespace" and return 0;
-	/[A-Z]+/ and warn "ColSpec '$_' is invalid because it contains upper case characters" and return 0;
-	/([^\#a-z0-9\-\_\.\!\*\?\[\]\{\}\:])/ and warn "ColSpec '$_' contains invalid characters ('$1')." and return 0;
-	/^\./ and warn "ColSpec '$_' is invalid: \".\" cannot be the first character" and return 0;
-	/\.$/ and warn "ColSpec '$_' is invalid: \".\" cannot be the last character (did you mean '$_*' ?)" and return 0;
-	
-	$_ =~ s/^\#//;
-		/\#/ and warn "ColSpec '$_' is invalid: # (comment) character may only be supplied at the begining of the string." and return 0;
-	
-	$_ =~ s/^\!//;
-	/\!/ and warn "ColSpec '$_' is invalid: ! (not) character may only be supplied at the begining of the string." and return 0;
 
-	return 1;
-};
+use Type::Tiny;
+my $TYPE_ColSpecStr = Type::Tiny->new(
+  name       => "ColSpecStr",
+  constraint => sub {
+    /\s+/ and warn "ColSpec '$_' is invalid because it contains whitespace" and return 0;
+    /[A-Z]+/ and warn "ColSpec '$_' is invalid because it contains upper case characters" and return 0;
+    /([^\#a-z0-9\-\_\.\!\*\?\[\]\{\}\:])/ and warn "ColSpec '$_' contains invalid characters ('$1')." and return 0;
+    /^\./ and warn "ColSpec '$_' is invalid: \".\" cannot be the first character" and return 0;
+    /\.$/ and warn "ColSpec '$_' is invalid: \".\" cannot be the last character (did you mean '$_*' ?)" and return 0;
+
+    $_ =~ s/^\#//;
+      /\#/ and warn "ColSpec '$_' is invalid: # (comment) character may only be supplied at the begining of the string." and return 0;
+
+    $_ =~ s/^\!//;
+    /\!/ and warn "ColSpec '$_' is invalid: ! (not) character may only be supplied at the begining of the string." and return 0;
+
+    return 1;
+  },
+  message => sub { "$_ not a ColSpecStr (see previous warnings)" }
+);
+sub ColSpecStr { $TYPE_ColSpecStr }
+
+subtype 'ColSpecStr', as 'Str', where { $TYPE_ColSpecStr->constraint->(@_) };
+
+has 'colspecs', is => 'ro', isa => 'ArrayRef[ColSpecStr]', required => 1;
+sub all_colspecs { uniq( @{(shift)->colspecs} ) }  
+sub add_colspecs { push @{(shift)->colspecs}, @_ }
 
-hasarray 'colspecs', isa => 'ArrayRef[ColSpecStr]', required => 1;
 
 # Store the orig/init colspec data in 'init_colspecs'
 has 'init_colspecs', is => 'ro', required => 1;
@@ -128,17 +140,20 @@ sub regen_subspec {
 }
 
 
-hasarray 'rel_order', lazy => 1, clearer => '_clear_rel_order', default => sub {
+has 'rel_order', is => 'ro', lazy => 1, clearer => '_clear_rel_order', default => sub {
 	my $self = shift;
 	return $self->_subspec_data->{order};
-};
+}, isa => 'ArrayRef';
+sub all_rel_order   { uniq( @{(shift)->rel_order} ) }  
+sub count_rel_order { scalar( (shift)->all_rel_order ) }
 
-hashash 'subspec', lazy => 1, clearer => '_clear_subspec', default => sub {
+has 'subspec', is => 'ro', lazy => 1, clearer => '_clear_subspec', default => sub {
 	my $self = shift;
 	my $data = $self->_subspec_data->{data};
 	return { '' => $self } unless ($self->count_rel_order > 1);
 	return { map { $_ => __PACKAGE__->new(colspecs => $data->{$_}) } keys %$data };
-};
+}, isa => 'HashRef';
+sub get_subspec { (shift)->subspec->{$_[0]} }
 
 
 
