@@ -7,7 +7,7 @@ use RapidApp::TableSpec::DbicTableSpec;
 use RapidApp::TableSpec::ColSpec;
 use RapidApp::TableSpec::Column::Profile;
 
-use RapidApp::Include qw(sugar perlutil);
+use RapidApp::Util qw(:all);
 
 use RapidApp::DBIC::Component::TableSpec;
 
@@ -50,22 +50,30 @@ default => sub {
 has 'schema', is => 'ro', lazy => 1, default => sub { (shift)->ResultSource->schema; };
 # ---
 
+use List::Util;
+
+sub _coerce_ColSpec {
+  my $v = $_[0];
+  ( # quick/dirty simulate from 'ArrayRef[Str]'
+    ref $v && ref($v) eq 'ARRAY' &&
+    !( List::Util::first { ref($_) || ! defined $_ } @$v )
+  ) ? RapidApp::TableSpec::ColSpec->new(colspecs => $v) : $v
+}
 
 subtype 'ColSpec', as 'Object';
-coerce 'ColSpec', from 'ArrayRef[Str]', 
-	via { RapidApp::TableSpec::ColSpec->new(colspecs => $_) };
+coerce 'ColSpec', from 'ArrayRef[Str]',	via { &_coerce_ColSpec($_) };
 
 has 'include_colspec', is => 'ro', isa => 'ColSpec', 
-	required => 1, coerce => 1, trigger =>  sub { (shift)->_colspec_attr_init_trigger(@_) };
+	required => 1, coerce => \&_coerce_ColSpec, trigger =>  sub { (shift)->_colspec_attr_init_trigger(@_) };
 	
 has 'updatable_colspec', is => 'ro', isa => 'ColSpec', 
-	default => sub {[]}, coerce => 1, trigger =>  sub { (shift)->_colspec_attr_init_trigger(@_) };
+	default => sub {[]}, coerce => \&_coerce_ColSpec, trigger =>  sub { (shift)->_colspec_attr_init_trigger(@_) };
 	
 has 'creatable_colspec', is => 'ro', isa => 'ColSpec', 
-	default => sub {[]}, coerce => 1, trigger => sub { (shift)->_colspec_attr_init_trigger(@_) };
+	default => sub {[]}, coerce => \&_coerce_ColSpec, trigger => sub { (shift)->_colspec_attr_init_trigger(@_) };
 	
 has 'always_fetch_colspec', is => 'ro', isa => 'ColSpec', 
-	default => sub {[]}, coerce => 1, trigger => sub { (shift)->_colspec_attr_init_trigger(@_) };
+	default => sub {[]}, coerce => \&_coerce_ColSpec, trigger => sub { (shift)->_colspec_attr_init_trigger(@_) };
 
 sub _colspec_attr_init_trigger {
 	my ($self,$ColSpec) = @_;
@@ -130,7 +138,9 @@ sub init_relspecs {
 }
 
 
-hashash 'column_data_alias';
+has 'column_data_alias', is => 'ro', isa => 'HashRef', default => sub {{}};
+sub apply_column_data_alias { my $h = (shift)->column_data_alias; %$h = ( %$h, @_ ) }
+
 has 'no_column_colspec', is => 'ro', isa => 'ColSpec', coerce => 1, default => sub {[]};
 sub expand_relationship_columns {
 	my $self = shift;
@@ -273,8 +283,11 @@ sub add_db_column($@) {
 
 # Load and process config params from TableSpec_cnf in the ResultClass plus
 # additional defaults:
-hashash 'Cnf_order';
-hashash 'Cnf', lazy => 1, default => sub {
+has 'Cnf_order', is => 'ro', isa => 'HashRef', default => sub {{}};
+sub get_Cnf_order { (shift)->Cnf_order->{$_[0]} }
+
+
+has 'Cnf', is => 'ro', lazy => 1, default => sub {
 	my $self = shift;
 	my $class = $self->ResultClass;
 	
@@ -295,7 +308,8 @@ hashash 'Cnf', lazy => 1, default => sub {
   
   %{$self->Cnf_order} = %{ $sim_order || {} };
   return $cf || {};
-};
+}, isa => 'HashRef';
+sub get_Cnf { (shift)->Cnf->{$_[0]} }
 
 has 'relationship_column_configs', is => 'ro', isa => 'HashRef', lazy_build => 1; 
 sub _build_relationship_column_configs {
@@ -1000,7 +1014,7 @@ around 'updated_column_order' => sub {
 
 
 
-hashash 'multi_rel_columns_indx', lazy => 1, default => sub {
+has 'multi_rel_columns_indx', is => 'ro', lazy => 1, default => sub {
 	my $self = shift;
 	my $list = $self->get_Cnf('multi_relationship_column_names') || [];
 	
@@ -1047,7 +1061,8 @@ hashash 'multi_rel_columns_indx', lazy => 1, default => sub {
 	#scream(\%indx);
 
 	return \%indx;
-};
+}, isa => 'HashRef';
+
 
 
 =head2 resolve_dbic_colname
@@ -1438,7 +1453,7 @@ sub chain_to_hash {
 }
 
 
-hashash 'relationship_column_render_column_map';
+has 'relationship_column_render_column_map', is => 'ro', isa => 'HashRef', default => sub {{}};
 sub get_relationship_column_cnf {
 	my $self = shift;
 	my $rel = shift;
@@ -1639,7 +1654,7 @@ sub get_relationship_column_cnf {
     $table = (split(/\./,$table,2))[1] || $table; #<-- get 'table' for both 'db.table' and 'table' format
     my $module_name = 'combo_' . $table . '_' . $colname;
     my $Module = $self->get_or_create_rapidapp_module( $module_name,
-      class	  => 'RapidApp::DbicAppCombo2',
+      class	  => 'RapidApp::Module::DbicCombo',
       params  => { %$params, %{ $conf->{auto_editor_params} } }
     );
     
@@ -1672,7 +1687,7 @@ sub get_relationship_column_cnf {
     $table = (split(/\./,$table,2))[1] || $table; #<-- get 'table' for both 'db.table' and 'table' format
     my $grid_module_name = 'grid_' . $table . '_' . $colname;
     my $GridModule = $self->get_or_create_rapidapp_module( $grid_module_name,
-      class	=> 'RapidApp::DbicAppGrid3',
+      class	=> 'RapidApp::Module::DbicGrid',
       params	=> {
         ResultSource => $Source,
         include_colspec => [ '*', '{?:single}*.*' ],
@@ -1892,7 +1907,7 @@ sub get_multi_relationship_column_cnf {
 	return %$conf;
 }
 
-hashash 'm2m_rel_columns_indx';
+has 'm2m_rel_columns_indx', is => 'ro', isa => 'HashRef', default => sub {{}};
 
 sub get_m2m_multi_relationship_column_cnf {
 	my $self = shift;
@@ -1934,7 +1949,7 @@ sub get_m2m_multi_relationship_column_cnf {
 	$table = (split(/\./,$table,2))[1] || $table; #<-- get 'table' for both 'db.table' and 'table' format
 	my $module_name = 'm2mcombo_' . $table . '_' . $colname;
 	my $Module = $self->get_or_create_rapidapp_module( $module_name,
-		class	=> 'RapidApp::DbicAppCombo2',
+		class	=> 'RapidApp::Module::DbicCombo',
 		params	=> {
 			valueField		=> $rrinfo->{cond_info}->{foreign},
 			displayField	=> $rrinfo->{cond_info}->{foreign},
@@ -2012,7 +2027,7 @@ sub get_or_create_rapidapp_module {
 
 	my $rootModule = RapidApp->_rootModule or die "Failed to find RapidApp Root Module!!";
 	
-	$rootModule->apply_init_modules( tablespec => 'RapidApp::AppBase' ) 
+	$rootModule->apply_init_modules( tablespec => 'RapidApp::Module' ) 
 		unless ( $rootModule->has_module('tablespec') );
 	
 	my $TMod = $rootModule->Module('tablespec');
